@@ -17,7 +17,7 @@ DRAC Lifecycle job specific methods
 
 from oslo_log import log as logging
 from oslo_utils import importutils
-import retrying
+import tenacity
 
 from ironic.common import exception
 from ironic.common.i18n import _
@@ -66,7 +66,8 @@ def get_job(node, job_id):
     except drac_exceptions.BaseClientException as exc:
         LOG.error('DRAC driver failed to get the job %(job_id)s '
                   'for node %(node_uuid)s. Reason: %(error)s.',
-                  {'node_uuid': node.uuid,
+                  {'job_id': job_id,
+                   'node_uuid': node.uuid,
                    'error': exc})
         raise exception.DracOperationError(error=exc)
 
@@ -90,10 +91,11 @@ def list_unfinished_jobs(node):
         raise exception.DracOperationError(error=exc)
 
 
-@retrying.retry(
-    retry_on_exception=lambda e: isinstance(e, exception.DracOperationError),
-    stop_max_attempt_number=CONF.drac.config_job_max_retries,
-    wait_fixed=WAIT_CLOCK * 1000)
+@tenacity.retry(
+    retry=tenacity.retry_if_exception_type(exception.DracOperationError),
+    stop=tenacity.stop_after_attempt(CONF.drac.config_job_max_retries),
+    wait=tenacity.wait_fixed(WAIT_CLOCK),
+    reraise=True)
 def wait_for_job_completion(node,
                             retries=CONF.drac.config_job_max_retries):
     """Wait for job to complete
@@ -109,6 +111,6 @@ def wait_for_job_completion(node,
         return
     err_msg = _(
         'There are unfinished jobs in the job '
-        'queue on node %(node_uuid)r ') % {'node_uuid': node.uuid}
+        'queue on node %(node_uuid)s.') % {'node_uuid': node.uuid}
     LOG.warning(err_msg)
     raise exception.DracOperationError(error=err_msg)
