@@ -21,10 +21,10 @@ from unittest import mock
 
 from glanceclient import client as glance_client
 from glanceclient import exc as glance_exc
-from keystoneauth1 import loading as kaloading
+from keystoneauth1 import loading as ks_loading
 from oslo_config import cfg
 from oslo_utils import uuidutils
-import retrying
+import tenacity
 import testtools
 
 from ironic.common import context
@@ -147,10 +147,11 @@ class TestGlanceImageService(base.TestCase):
             'os_hash_algo': None,
             'os_hash_value': None,
         }
-        with mock.patch.object(self.service, 'call', return_value=image,
-                               autospec=True):
-            image_meta = self.service.show(image_id)
-            self.service.call.assert_called_once_with('get', image_id)
+        if not mock._is_instance_mock(self.service.call):
+            mock.patch.object(self.service, 'call', autospec=True).start()
+        self.service.call.return_value = image
+        image_meta = self.service.show(image_id)
+        self.service.call.assert_called_with('get', image_id)
         self.assertEqual(expected, image_meta)
 
     def test_show_makes_datetimes(self):
@@ -163,8 +164,11 @@ class TestGlanceImageService(base.TestCase):
         self.assertEqual(self.NOW_DATETIME, image_meta['created_at'])
         self.assertEqual(self.NOW_DATETIME, image_meta['updated_at'])
 
-    def test_show_raises_when_no_authtoken_in_the_context(self):
+    @mock.patch.object(service_utils, 'is_image_active', autospec=True)
+    def test_show_raises_when_no_authtoken_in_the_context(self,
+                                                          mock_is_active):
         self.context.auth_token = False
+        mock_is_active.return_value = True
         self.assertRaises(exception.ImageNotFound,
                           self.service.show,
                           uuidutils.generate_uuid())
@@ -172,13 +176,13 @@ class TestGlanceImageService(base.TestCase):
     def test_show_raises_when_image_not_active(self):
         image_id = uuidutils.generate_uuid()
         image = self._make_fixture(name='image1', id=image_id, status="queued")
-        with mock.patch.object(self.service, 'call', return_value=image,
-                               autospec=True):
-            self.assertRaises(exception.ImageUnacceptable,
-                              self.service.show, image_id)
+        if not mock._is_instance_mock(self.service.call):
+            mock.patch.object(self.service, 'call', autospec=True).start()
+        self.service.call.return_value = image
+        self.assertRaises(exception.ImageUnacceptable,
+                          self.service.show, image_id)
 
-    @mock.patch.object(retrying.time, 'sleep', autospec=True)
-    def test_download_with_retries(self, mock_sleep):
+    def test_download_with_retries(self):
         tries = [0]
 
         class MyGlanceStubClient(stubs.StubGlanceClient):
@@ -196,22 +200,24 @@ class TestGlanceImageService(base.TestCase):
         stub_context.project_id = 'fake'
         stub_service = image_service.GlanceImageService(stub_client,
                                                         stub_context)
+        stub_service.call.retry.sleep = mock.Mock()
         image_id = uuidutils.generate_uuid()
         writer = NullWriter()
 
-        # When retries are disabled, we should get an exception
-        self.config(num_retries=0, group='glance')
-        self.assertRaises(exception.GlanceConnectionFailed,
-                          stub_service.download, image_id, writer)
+        with mock.patch.object(tenacity, 'retry', autospec=True) as mock_retry:
+            # When retries are disabled, we should get an exception
+            self.config(num_retries=0, group='glance')
+            self.assertRaises(exception.GlanceConnectionFailed,
+                              stub_service.download, image_id, writer)
 
-        # Now lets enable retries. No exception should happen now.
-        self.config(num_retries=1, group='glance')
-        importlib.reload(image_service)
-        stub_service = image_service.GlanceImageService(stub_client,
-                                                        stub_context)
-        tries = [0]
-        stub_service.download(image_id, writer)
-        self.assertTrue(mock_sleep.called)
+            # Now lets enable retries. No exception should happen now.
+            self.config(num_retries=1, group='glance')
+            importlib.reload(image_service)
+            stub_service = image_service.GlanceImageService(stub_client,
+                                                            stub_context)
+            tries = [0]
+            stub_service.download(image_id, writer)
+            mock_retry.assert_called_once()
 
     def test_download_no_data(self):
         self.client.fake_wrapped = None
@@ -224,7 +230,7 @@ class TestGlanceImageService(base.TestCase):
                                    'image contains no data',
                                    self.service.download, image_id)
 
-    @mock.patch('sendfile.sendfile', autospec=True)
+    @mock.patch('os.sendfile', autospec=True)
     @mock.patch('os.path.getsize', autospec=True)
     @mock.patch('%s.open' % __name__, new=mock.mock_open(), create=True)
     def test_download_file_url(self, mock_getsize, mock_sendfile):
@@ -353,8 +359,8 @@ class CheckImageServiceTestCase(base.TestCase):
         self.context = context.RequestContext(global_request_id='global')
         self.service = image_service.GlanceImageService(None, self.context)
         # NOTE(pas-ha) register keystoneauth dynamic options manually
-        plugin = kaloading.get_plugin_loader('password')
-        opts = kaloading.get_auth_plugin_conf_options(plugin)
+        plugin = ks_loading.get_plugin_loader('password')
+        opts = ks_loading.get_auth_plugin_conf_options(plugin)
         self.cfg_fixture.register_opts(opts, group='glance')
         self.config(auth_type='password',
                     auth_url='viking',
@@ -599,6 +605,62 @@ class TestGlanceSwiftTempURL(base.TestCase):
             method='GET')
         swift_mock.assert_called_once_with()
 
+    @mock.patch('ironic.common.swift.get_swift_session', autospec=True)
+    @mock.patch('swiftclient.utils.generate_temp_url', autospec=True)
+    def test_swift_temp_url_account_detected_with_prefix(self, tempurl_mock,
+                                                         swift_mock):
+        self.config(swift_account=None, group='glance')
+        self.config(swift_account_prefix='SWIFTPREFIX', group='glance')
+
+        path = ('/v1/SWIFTPREFIX_42/glance'
+                '/757274c4-2856-4bd2-bb20-9a4a231e187b')
+        tempurl_mock.return_value = (
+            path + '?temp_url_sig=hmacsig&temp_url_expires=1400001200')
+        auth_ref = swift_mock.return_value.auth.get_auth_ref.return_value
+        auth_ref.project_id = '42'
+
+        self.service._validate_temp_url_config = mock.Mock()
+
+        temp_url = self.service.swift_temp_url(image_info=self.fake_image)
+
+        self.assertEqual(CONF.glance.swift_endpoint_url
+                         + tempurl_mock.return_value,
+                         temp_url)
+        tempurl_mock.assert_called_with(
+            path=path,
+            seconds=CONF.glance.swift_temp_url_duration,
+            key=CONF.glance.swift_temp_url_key,
+            method='GET')
+        swift_mock.assert_called_once_with()
+
+    @mock.patch('ironic.common.swift.get_swift_session', autospec=True)
+    @mock.patch('swiftclient.utils.generate_temp_url', autospec=True)
+    def test_swift_temp_url_account_detected_with_prefix_underscore(
+            self, tempurl_mock, swift_mock):
+        self.config(swift_account=None, group='glance')
+        self.config(swift_account_prefix='SWIFTPREFIX_', group='glance')
+
+        path = ('/v1/SWIFTPREFIX_42/glance'
+                '/757274c4-2856-4bd2-bb20-9a4a231e187b')
+        tempurl_mock.return_value = (
+            path + '?temp_url_sig=hmacsig&temp_url_expires=1400001200')
+        auth_ref = swift_mock.return_value.auth.get_auth_ref.return_value
+        auth_ref.project_id = '42'
+
+        self.service._validate_temp_url_config = mock.Mock()
+
+        temp_url = self.service.swift_temp_url(image_info=self.fake_image)
+
+        self.assertEqual(CONF.glance.swift_endpoint_url
+                         + tempurl_mock.return_value,
+                         temp_url)
+        tempurl_mock.assert_called_with(
+            path=path,
+            seconds=CONF.glance.swift_temp_url_duration,
+            key=CONF.glance.swift_temp_url_key,
+            method='GET')
+        swift_mock.assert_called_once_with()
+
     @mock.patch('ironic.common.swift.SwiftAPI', autospec=True)
     @mock.patch('swiftclient.utils.generate_temp_url', autospec=True)
     def test_swift_temp_url_key_detected(self, tempurl_mock, swift_mock):
