@@ -274,26 +274,86 @@ class IronicImagesTestCase(base.TestCase):
     def test_is_whole_disk_image_partition_non_glance(self, mock_igi,
                                                       mock_gip):
         mock_igi.return_value = False
-        instance_info = {'image_source': 'partition_image',
-                         'kernel': 'kernel',
-                         'ramdisk': 'ramdisk'}
+        instance_info = {
+            'image_source': 'fcf5a777-d9d2-4b86-b3da-bb0b61d5a291',
+            'kernel': 'kernel',
+            'ramdisk': 'ramdisk'}
         is_whole_disk_image = images.is_whole_disk_image('context',
                                                          instance_info)
         self.assertFalse(is_whole_disk_image)
         self.assertFalse(mock_gip.called)
         mock_igi.assert_called_once_with(instance_info['image_source'])
 
+    @mock.patch.object(image_service.HttpImageService, 'validate_href',
+                       autospec=True)
     @mock.patch.object(images, 'get_image_properties', autospec=True)
     @mock.patch.object(glance_utils, 'is_glance_image', autospec=True)
     def test_is_whole_disk_image_whole_disk_non_glance(self, mock_igi,
-                                                       mock_gip):
+                                                       mock_gip,
+                                                       mock_validate):
         mock_igi.return_value = False
-        instance_info = {'image_source': 'whole_disk_image'}
+        instance_info = {
+            'image_source': 'http://whole-disk-image'}
         is_whole_disk_image = images.is_whole_disk_image('context',
                                                          instance_info)
         self.assertTrue(is_whole_disk_image)
         self.assertFalse(mock_gip.called)
         mock_igi.assert_called_once_with(instance_info['image_source'])
+        mock_validate.assert_called_once_with(mock.ANY,
+                                              'http://whole-disk-image')
+
+    def test_is_source_a_path_returns_none(self):
+        self.assertIsNone(images.is_source_a_path('context', {}))
+
+    @mock.patch.object(image_service.HttpImageService, 'validate_href',
+                       autospec=True)
+    def test_is_source_a_path_simple(self, validate_mock):
+        mock_response = mock.Mock()
+        mock_response.headers = {}
+        validate_mock.return_value = mock_response
+        self.assertTrue(images.is_source_a_path('context', 'http://foo/bar/'))
+        validate_mock.assert_called_once_with(mock.ANY, 'http://foo/bar/')
+
+    @mock.patch.object(image_service.HttpImageService, 'validate_href',
+                       autospec=True)
+    def test_is_source_a_path_content_length(self, validate_mock):
+        mock_response = mock.Mock()
+        mock_response.headers = {'Content-Length': 1}
+        validate_mock.return_value = mock_response
+        self.assertFalse(images.is_source_a_path('context', 'http://foo/bar/'))
+        validate_mock.assert_called_once_with(mock.ANY, 'http://foo/bar/')
+
+    @mock.patch.object(image_service.HttpImageService, 'validate_href',
+                       autospec=True)
+    def test_is_source_a_path_content_type(self, validate_mock):
+        mock_response = mock.Mock()
+        mock_response.headers = {'Content-Type': 'text/html'}
+        validate_mock.return_value = mock_response
+        self.assertTrue(images.is_source_a_path('context', 'http://foo/bar'))
+        validate_mock.assert_called_once_with(mock.ANY, 'http://foo/bar')
+
+    @mock.patch.object(images, 'LOG', autospec=True)
+    @mock.patch.object(image_service.HttpImageService, 'validate_href',
+                       autospec=True)
+    def test_is_source_a_path_redirect(self, validate_mock, log_mock):
+        url = 'http://foo/bar'
+        redirect_url = url + '/'
+        validate_mock.side_effect = exception.ImageRefIsARedirect(
+            url, redirect_url)
+        self.assertTrue(images.is_source_a_path('context', url))
+        log_mock.debug.assert_called_once_with('Received a URL redirect when '
+                                               'attempting to evaluate image '
+                                               'reference http://foo/bar '
+                                               'pointing to http://foo/bar/. '
+                                               'This may, or may not be '
+                                               'recoverable.')
+
+    @mock.patch.object(image_service.HttpImageService, 'validate_href',
+                       autospec=True)
+    def test_is_source_a_path_other_error(self, validate_mock):
+        url = 'http://foo/bar'
+        validate_mock.side_effect = OSError
+        self.assertIsNone(images.is_source_a_path('context', url))
 
 
 class FsImageTestCase(base.TestCase):
@@ -740,16 +800,16 @@ class FsImageTestCase(base.TestCase):
             boot_mode='uefi')
 
         fetch_images_mock.assert_any_call(
-            'ctx', 'kernel-uuid', 'tmpdir/kernel-uuid')
+            'ctx', 'kernel-uuid', 'tmpdir/kernel')
         fetch_images_mock.assert_any_call(
-            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk-uuid')
+            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk')
         fetch_images_mock.assert_any_call(
-            'ctx', 'deploy_iso-uuid', 'tmpdir/deploy_iso-uuid')
+            'ctx', 'deploy_iso-uuid', 'tmpdir/iso')
 
         params = ['root=UUID=root-uuid', 'kernel-params']
         create_isolinux_mock.assert_called_once_with(
-            'output_file', 'tmpdir/kernel-uuid', 'tmpdir/ramdisk-uuid',
-            deploy_iso='tmpdir/deploy_iso-uuid',
+            'output_file', 'tmpdir/kernel', 'tmpdir/ramdisk',
+            deploy_iso='tmpdir/iso',
             esp_image=None, kernel_params=params, inject_files=None)
 
     @mock.patch.object(images, 'create_esp_image_for_uefi', autospec=True)
@@ -768,16 +828,16 @@ class FsImageTestCase(base.TestCase):
             boot_mode='uefi')
 
         fetch_images_mock.assert_any_call(
-            'ctx', 'kernel-uuid', 'tmpdir/kernel-uuid')
+            'ctx', 'kernel-uuid', 'tmpdir/kernel')
         fetch_images_mock.assert_any_call(
-            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk-uuid')
+            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk')
         fetch_images_mock.assert_any_call(
-            'ctx', 'efiboot-uuid', 'tmpdir/efiboot-uuid')
+            'ctx', 'efiboot-uuid', 'tmpdir/esp')
 
         params = ['root=UUID=root-uuid', 'kernel-params']
         create_isolinux_mock.assert_called_once_with(
-            'output_file', 'tmpdir/kernel-uuid', 'tmpdir/ramdisk-uuid',
-            deploy_iso=None, esp_image='tmpdir/efiboot-uuid',
+            'output_file', 'tmpdir/kernel', 'tmpdir/ramdisk',
+            deploy_iso=None, esp_image='tmpdir/esp',
             kernel_params=params, inject_files=None)
 
     @mock.patch.object(images, 'create_esp_image_for_uefi', autospec=True)
@@ -796,16 +856,16 @@ class FsImageTestCase(base.TestCase):
             boot_mode='uefi')
 
         expected_calls = [mock.call('ctx', 'http://kernel-href',
-                                    'tmpdir/kernel-href'),
+                                    'tmpdir/kernel'),
                           mock.call('ctx', 'http://ramdisk-href',
-                                    'tmpdir/ramdisk-href'),
+                                    'tmpdir/ramdisk'),
                           mock.call('ctx', 'http://deploy_iso-href',
-                                    'tmpdir/deploy_iso-href')]
+                                    'tmpdir/iso')]
         fetch_images_mock.assert_has_calls(expected_calls)
         params = ['root=UUID=root-uuid', 'kernel-params']
         create_isolinux_mock.assert_called_once_with(
-            'output_file', 'tmpdir/kernel-href', 'tmpdir/ramdisk-href',
-            deploy_iso='tmpdir/deploy_iso-href',
+            'output_file', 'tmpdir/kernel', 'tmpdir/ramdisk',
+            deploy_iso='tmpdir/iso',
             esp_image=None, kernel_params=params, inject_files=None)
 
     @mock.patch.object(images, 'create_esp_image_for_uefi', autospec=True)
@@ -824,16 +884,16 @@ class FsImageTestCase(base.TestCase):
             boot_mode='uefi')
 
         expected_calls = [mock.call('ctx', 'http://kernel-href',
-                                    'tmpdir/kernel-href'),
+                                    'tmpdir/kernel'),
                           mock.call('ctx', 'http://ramdisk-href',
-                                    'tmpdir/ramdisk-href'),
+                                    'tmpdir/ramdisk'),
                           mock.call('ctx', 'http://efiboot-href',
-                                    'tmpdir/efiboot-href')]
+                                    'tmpdir/esp')]
         fetch_images_mock.assert_has_calls(expected_calls)
         params = ['root=UUID=root-uuid', 'kernel-params']
         create_isolinux_mock.assert_called_once_with(
-            'output_file', 'tmpdir/kernel-href', 'tmpdir/ramdisk-href',
-            deploy_iso=None, esp_image='tmpdir/efiboot-href',
+            'output_file', 'tmpdir/kernel', 'tmpdir/ramdisk',
+            deploy_iso=None, esp_image='tmpdir/esp',
             kernel_params=params, inject_files=None)
 
     @mock.patch.object(images, 'create_isolinux_image_for_bios', autospec=True)
@@ -851,9 +911,9 @@ class FsImageTestCase(base.TestCase):
                                'kernel-params', 'bios')
 
         fetch_images_mock.assert_any_call(
-            'ctx', 'kernel-uuid', 'tmpdir/kernel-uuid')
+            'ctx', 'kernel-uuid', 'tmpdir/kernel')
         fetch_images_mock.assert_any_call(
-            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk-uuid')
+            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk')
 
         # Note (NobodyCam): the original assert asserted that fetch_images
         #                   was not called with parameters, this did not
@@ -864,7 +924,7 @@ class FsImageTestCase(base.TestCase):
 
         params = ['root=UUID=root-uuid', 'kernel-params']
         create_isolinux_mock.assert_called_once_with(
-            'output_file', 'tmpdir/kernel-uuid', 'tmpdir/ramdisk-uuid',
+            'output_file', 'tmpdir/kernel', 'tmpdir/ramdisk',
             kernel_params=params, inject_files=None)
 
     @mock.patch.object(images, 'create_isolinux_image_for_bios', autospec=True)
@@ -883,13 +943,13 @@ class FsImageTestCase(base.TestCase):
                                'kernel-params', None)
 
         fetch_images_mock.assert_any_call(
-            'ctx', 'kernel-uuid', 'tmpdir/kernel-uuid')
+            'ctx', 'kernel-uuid', 'tmpdir/kernel')
         fetch_images_mock.assert_any_call(
-            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk-uuid')
+            'ctx', 'ramdisk-uuid', 'tmpdir/ramdisk')
 
         params = ['root=UUID=root-uuid', 'kernel-params']
         create_isolinux_mock.assert_called_once_with(
-            'output_file', 'tmpdir/kernel-uuid', 'tmpdir/ramdisk-uuid',
+            'output_file', 'tmpdir/kernel', 'tmpdir/ramdisk',
             kernel_params=params, inject_files=None)
 
     @mock.patch.object(image_service, 'get_image_service', autospec=True)
